==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Effect/soxr/soxresampler.h <==
/***************************************************************************
 *   Copyright (C) 2016 by Ilya Kotov                                      *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef SRCONVERTER_H
#define SRCONVERTER_H

#include <soxr.h>
#include <qmmp/effect.h>

/**
    @author Ilya Kotov <forkotov02@ya.ru>
*/

class SoXResampler : public Effect
{
public:
    SoXResampler();
    virtual ~SoXResampler();

    void applyEffect(Buffer *b) override;
    void configure(quint32 freq, ChannelMap map) override;

private:
    void freeSoXR();
    quint32 m_overSamplingFs;
    float *m_out;
    size_t m_out_samples;
    soxr_quality_spec_t m_quality;
    soxr_t m_soxr;

};

#endif

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Effect/soxr/soxresampler.h <==
/***************************************************************************
 *   Copyright (C) 2016-2022 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef SRCONVERTER_H
#define SRCONVERTER_H

#include <soxr.h>
#include <qmmp/effect.h>

/**
    @author Ilya Kotov <forkotov02@ya.ru>
*/

class SoXResampler : public Effect
{
public:
    SoXResampler();
    virtual ~SoXResampler();

    void applyEffect(Buffer *b) override;
    void configure(quint32 freq, ChannelMap map) override;

private:
    void freeSoXR();
    quint32 m_overSamplingFs;
    float *m_out = nullptr;
    size_t m_out_samples = 0;
    soxr_quality_spec_t m_quality;
    soxr_t m_soxr = nullptr;

};

#endif
